==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/sql.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function SqlConnect($host,$user,$pass,$p=1) {
   if ($p) $ret = @mysql_pconnect($host,$user,$pass);
   else $ret = @mysql_connect($host,$user,$pass);
   return $ret ? $ret : SqlError();
}

function SqlCreateDb($db) {
   $ret = @mysql_create_db($db);
   return $ret ? $ret : SqlError();
}

function SqlSelectDb($db) {
   $ret = @mysql_select_db($db);
   return $ret ? $ret : SqlError();
}

function SqlQuery($query) {
   global $sql_link;
   /* $GLOBALS["sql_calls"]++; # for debug */
   $ret = mysql_query($query,$sql_link);
   return $ret ? $ret : SqlError();
}

function SqlInsertId() {
   global $sql_link;
   return @mysql_insert_id($sql_link);
}

function SqlQueryFetchArray($query) {
   $result  = SqlQuery($query);
   if(@mysql_num_rows($result)) { 
      $ret = array();
      $ret = mysql_fetch_array($result);
      @mysql_free_result($result);
      return $ret;
   }
}

/*
function SqlResult($query,$r=0) {
   $result  = SqlQuery($query);
   if(@mysql_num_rows($result)) { 
      $tmp = mysql_result($result,$r);
      @mysql_free_result($result);
   }
   return $tmp;
}
*/

function SqlResult($query) {
   $result  = SqlQuery($query);
   if(mysql_num_rows($result)) {
      $ret = mysql_fetch_row($result);
      mysql_free_result($result);
      return $ret[0];
   } else return false;
}

function SqlFetchRow($result) {
   return mysql_num_rows($result) ? mysql_fetch_row($result) : 0;
}

function SqlReturnArray($sql) {
   $result  = SqlQuery($sql);
   if (mysql_num_rows($result)) {
      $data = array();
      while ($row = mysql_fetch_array($result)) $data[] = $row;
      mysql_free_result($result);
      return $data;
   }
}

function SqlListsDbs($link) {
   $result = @mysql_list_dbs($link);
   if(mysql_num_rows($result)) {
      $dblist = array();
      while ($row = mysql_fetch_array($result)) { 
         $dblist[] = $row['Database'];
      }
      return $dblist;
   }
}

function SqlExistDb($dbname,$link) {
   $db_list = SqlListsDbs($link);
   if (in_array($dbname,$db_list)) return true;
   else return false;
}

function SqlGetTables($db) {
   $result = @mysql_list_tables($db);
   $num = @mysql_num_rows($result);
   $i = 0;
   $name = array();
   while ($i < $num) {
      $name[] = @mysql_tablename($result, $i);
      $i++;
   }
   @mysql_free_result($result);
   return $name;
}

function SqlExistTable($table,$db) {
   $tables = SqlGetTables($db);
   if (in_array($table,$tables)) return true;
   else return false;
}

function SqlGetFields($db,$table,$link) {
   $fields = mysql_list_fields($db,$table,$link);
   $cols = mysql_num_fields($fields);
   for ($i = 0; $i < $cols; $i++) {
      $name = mysql_field_name($fields, $i);
      $ret[$name]['type'] = mysql_field_type($fields, $i);
      $ret[$name]['len'] = mysql_field_len($fields, $i);
      $ret[$name]['flag'] = mysql_field_flags($fields, $i);
   }
   return $ret;
}

function SqlExistField($db,$table,$link,$field) {
   $fields = SqlGetFields($db,$table,$link);
   $names = array_keys($fields);
   if (in_array($field,$names)) return true;
   else return false;
}

function SqlError() {
   die("Problem in SQL Server" . "\n [".@mysql_errno()."]: ".@mysql_error());
}

function SqlCount($table,$field='',$what='',$field2='',$what2='') {
	$sql	= "SELECT COUNT(*) FROM $table";
	if (!empty($what))  $sql .= " WHERE $field = '$what'";
	if (!empty($what2)) $sql .= " AND $field2 = '$what2'";
	return SqlResult($sql);
}

function KWL_UpHits($tbl,$rid) {
   if (KWL_ValidRid($rid)) {
      SqlQuery("UPDATE $tbl set Hits = Hits + 1 WHERE Rid = '$rid'");
   }
}

function KWL_GetScore($rid) {
   $sql  = "SELECT COUNT(1/(score >= 0)) C0, COUNT(1/(score = 1)) C1 ";
   $sql .= "FROM T_Comments WHERE TopRid = '$rid'";
   return SqlQueryFetchArray($sql);
}

function KWL_GetStory($rid,$field="") {
   if (KWL_ValidRid($rid)) {
      if (!empty($filed)) $sql = "SELECT $field ";
      else $sql = "SELECT * ";
      $sql .= "FROM T_Stories WHERE Rid = '$rid' ";
      if (KWL_GetConf("Moderation")) $sql .= "AND Verified = 'Y'";
      $ret = SqlQueryFetchArray($sql);
      return is_array($ret) ? $ret : false;
   } else return false;
}

function KWL_NumsByTopic($topic) {
   static $nums_by_topic;
   if (!isset($nums_by_topic)) {
      $rt = SqlQuery("SELECT Topic, COUNT(*) FROM T_Stories WHERE Verified = 'Y' GROUP BY Topic");
      while ($k = mysql_fetch_array($rt)) $nums_by_topic[$k[0]] = $k[1];
   }
   return $nums_by_topic[$topic];
}

function KWL_NewStory($story,$fix=0) {
   global $C_STORY;

   if (!KWL_ValidRid($story)) return;
   $C_STORY = KWL_GetStory($story);
   $A = $C_STORY;

   #  з ֱٱ 5
   $sql= "SELECT Rid,Heading FROM T_Stories WHERE Topic = '$A[Topic]' ";
   $sql .= "AND Verified = 'Y' ";
   $sql .= "ORDER BY Repostamp DESC LIMIT 5";
   $result= SqlQuery($sql);
   $tmp = "";

   while ($A = mysql_fetch_array($result)){
      if ($fix) $tmp .= "<LI><A HREF=\"" . KWL_MakeStoryLink($A["Rid"]) . "\">$A[Heading]</A>\n";
      else $tmp .= "myScroller1.addItem(\"<CENTER><A HREF=\\\"" . KWL_MakeStoryLink($A["Rid"]) . "\\\">". addslashes($A['Heading']) ."</A></CENTER>\");\n";
   }
   @mysql_free_result($result);
   return $tmp;
}

function KWL_NP_Story($Repostamp,$Topic="") {
   $ret = "";
   $sql= "SELECT Rid,Heading FROM T_Stories WHERE Verified = 'Y' AND ";
   $sql .= "Repostamp > '$Repostamp' ORDER BY Repostamp ASC LIMIT 1";
   $result= SqlQuery($sql);

   if ($A = mysql_fetch_array($result)) {
      $ret = "&lt;&nbsp;&nbsp;<A HREF=\"stories.php?story=$A[Rid]\">$A[Heading]</A> | ";
   }
   
   $sql= "SELECT Rid,Heading FROM T_Stories WHERE Verified = 'Y' AND ";
   $sql .= "Repostamp < '$Repostamp' ORDER BY Repostamp DESC LIMIT 1";
   $result= SqlQuery($sql);
   if ($A = mysql_fetch_array($result)){
      $ret .= "<A HREF=\"stories.php?story=$A[Rid]\">$A[Heading]</A>&nbsp;&nbsp;&gt;";
   }
   return "<CENTER><FONT SIZE=\"-1\">$ret</FONT></CENTER>\n";
}
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/include/sql.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function SqlConnect($host,$user,$pass,$p=1) {
   if ($p) $ret = @mysql_pconnect($host,$user,$pass);
   else $ret = @mysql_connect($host,$user,$pass);
   return $ret ? $ret : SqlError();
}

function SqlCreateDb($db) {
   $ret = @mysql_create_db($db);
   return $ret ? $ret : SqlError();
}

function SqlSelectDb($db) {
   $ret = @mysql_select_db($db);
   return $ret ? $ret : SqlError();
}

function SqlQuery($query) {
   global $sql_link;
   /* $GLOBALS["sql_calls"]++; # for debug */
   $ret = mysql_query($query,$sql_link);
   return $ret ? $ret : SqlError();
}

function SqlInsertId() {
   global $sql_link;
   return @mysql_insert_id($sql_link);
}

function SqlQueryFetchArray($query) {
   $result  = SqlQuery($query);
   if(@mysql_num_rows($result)) { 
      $ret = array();
      $ret = mysql_fetch_array($result);
      @mysql_free_result($result);
      return $ret;
   }
}

/*
function SqlResult($query,$r=0) {
   $result  = SqlQuery($query);
   if(@mysql_num_rows($result)) { 
      $tmp = mysql_result($result,$r);
      @mysql_free_result($result);
   }
   return $tmp;
}
*/

function SqlResult($query) {
   $result  = SqlQuery($query);
   if(mysql_num_rows($result)) {
      $ret = mysql_fetch_row($result);
      mysql_free_result($result);
      return $ret[0];
   } else return false;
}

function SqlFetchRow($result) {
   return mysql_num_rows($result) ? mysql_fetch_row($result) : 0;
}

function SqlReturnArray($sql) {
   $result  = SqlQuery($sql);
   if (mysql_num_rows($result)) {
      $data = array();
      while ($row = mysql_fetch_array($result)) $data[] = $row;
      mysql_free_result($result);
      return $data;
   }
}

function SqlListsDbs($link) {
   $result = @mysql_list_dbs($link);
   if(mysql_num_rows($result)) {
      $dblist = array();
      while ($row = mysql_fetch_array($result)) { 
         $dblist[] = $row['Database'];
      }
      return $dblist;
   }
}

function SqlExistDb($dbname,$link) {
   $db_list = SqlListsDbs($link);
   if (in_array($dbname,$db_list)) return true;
   else return false;
}

function SqlGetTables($db) {
   $result = @mysql_list_tables($db);
   $num = @mysql_num_rows($result);
   $i = 0;
   $name = array();
   while ($i < $num) {
      $name[] = @mysql_tablename($result, $i);
      $i++;
   }
   @mysql_free_result($result);
   return $name;
}

function SqlExistTable($table,$db) {
   $tables = SqlGetTables($db);
   if (in_array($table,$tables)) return true;
   else return false;
}

function SqlGetFields($db,$table,$link) {
   $fields = mysql_list_fields($db,$table,$link);
   $cols = mysql_num_fields($fields);
   for ($i = 0; $i < $cols; $i++) {
      $name = mysql_field_name($fields, $i);
      $ret[$name]['type'] = mysql_field_type($fields, $i);
      $ret[$name]['len'] = mysql_field_len($fields, $i);
      $ret[$name]['flag'] = mysql_field_flags($fields, $i);
   }
   return $ret;
}

function SqlExistField($db,$table,$link,$field) {
   $fields = SqlGetFields($db,$table,$link);
   $names = array_keys($fields);
   if (in_array($field,$names)) return true;
   else return false;
}

function SqlError() {
   die("Problem in SQL Server" . "\n [".@mysql_errno()."]: ".@mysql_error());
}

function SqlCount($table,$field='',$what='',$field2='',$what2='') {
	$sql	= "SELECT COUNT(*) FROM $table";
	if (!empty($what))  $sql .= " WHERE $field = '$what'";
	if (!empty($what2)) $sql .= " AND $field2 = '$what2'";
	return SqlResult($sql);
}

function KWL_UpHits($tbl,$rid) {
   if (KWL_ValidRid($rid)) {
      SqlQuery("UPDATE $tbl set Hits = Hits + 1 WHERE Rid = '$rid'");
   }
}

function KWL_GetScore($rid) {
   $sql  = "SELECT COUNT(1/(score >= 0)) C0, COUNT(1/(score = 1)) C1 ";
   $sql .= "FROM T_Comments WHERE TopRid = '$rid'";
   return SqlQueryFetchArray($sql);
}

function KWL_GetStory($rid,$field="") {
   if (KWL_ValidRid($rid)) {
      if (!empty($filed)) $sql = "SELECT $field ";
      else $sql = "SELECT * ";
      $sql .= "FROM T_Stories WHERE Rid = '$rid' ";
      if (KWL_GetConf("Moderation")) $sql .= "AND Verified = 'Y'";
      $ret = SqlQueryFetchArray($sql);
      return is_array($ret) ? $ret : false;
   } else return false;
}

function KWL_NumsByTopic($topic) {
   static $nums_by_topic;
   if (!isset($nums_by_topic)) {
      $rt = SqlQuery("SELECT Topic, COUNT(*) FROM T_Stories WHERE Verified = 'Y' GROUP BY Topic");
      while ($k = mysql_fetch_array($rt)) $nums_by_topic[$k[0]] = $k[1];
   }
   return $nums_by_topic[$topic];
}

function KWL_NewStory($story) {
   global $C_STORY;

   $CONF = KWL_GetConf();
   if (!KWL_ValidRid($story)) return;
   $C_STORY = KWL_GetStory($story);
   $A = $C_STORY;

   #  з ֱٱ 5
   $sql= "SELECT Rid,Heading FROM T_Stories WHERE Topic = '$A[Topic]' ";
   $sql .= "AND Verified = 'Y' ";
   $sql .= "ORDER BY Repostamp DESC LIMIT 5";
   $result= SqlQuery($sql);
   $ret = "";

   while ($A = mysql_fetch_array($result)){
      $ret .= $CONF['dotchar'] . "<a href=\"" . KWL_MakeStoryLink($A["Rid"]) . "\">$A[Heading]</a><br /><br />\n";
   }
   @mysql_free_result($result);
   return $ret;
}

function KWL_NP_Story($Repostamp,$Topic="") {
   $ret = "";
   $sql= "SELECT Rid,Heading FROM T_Stories WHERE Verified = 'Y' AND ";
   $sql .= "Repostamp > '$Repostamp' ORDER BY Repostamp ASC LIMIT 1";
   $result= SqlQuery($sql);

   if ($A = mysql_fetch_array($result)) {
      $ret = "&lt;&nbsp;&nbsp;<a href=\"stories.php?story=$A[Rid]\">$A[Heading]</a> | ";
   }
   
   $sql= "SELECT Rid,Heading FROM T_Stories WHERE Verified = 'Y' AND ";
   $sql .= "Repostamp < '$Repostamp' ORDER BY Repostamp DESC LIMIT 1";
   $result= SqlQuery($sql);
   if ($A = mysql_fetch_array($result)){
      $ret .= "<a href=\"stories.php?story=$A[Rid]\">$A[Heading]</a>&nbsp;&nbsp;&gt;";
   }
   return "<center>$ret</center>\n";
}
?>
